' This script is an example to prepare an xml file programmatically to process by memoQ xml filters. 
' The sample xml code: 
' <strings>
' 	<msg ID="001">
' 		<en>
' 			This is the message
' 			<!-- This is comment -->
' 		</en>
' 	</msg>
' </strings>

' The script adds the specified language codes as a child element to msg element, and creates a comment tag to specify the comment as a memoQ comment.


' Syntax:
' XmlPrep.vbs 
' 					[/LanguageList:<tag names separated by commas, no space>]
' 					[/Comment:yes/no]
' 					/InputFile:{inputfilepath} 
' 					/OutputFile:{outputfilepath}

' Example:
' XmlPrep.vbs /LanguageList:it,de,es,fr /Comment:no /InputFile:{inputfilepath} /OutputFile:{outputfilepath}
 

' If the Comment attribute is not specified, the comments will not be converted. The multilingual xml filter can handle 
' comments as memoQ comments. However, normal xml filter can only interpret comments as tags. To use them as memoQ 
' comments, they need to be converted to xml elements. 
' If the LanguageList attribute is not specified, there will be no change to the language elements.
' For input and output files simply use the default {inputfilepath} and {outputfilepath} attribute offered by 
' memoQ template editor. 

' Before finalizing the memoQ template, run the test feature, so to make sure the script works properly.

Dim strLangList, strComment, strInputFile, strOutputFile
Dim strLang
Dim arrLangList
Dim bComment
Dim objArguments
Dim xmlDoc
Dim objRoot
Dim objNode, objCNode, objPNode


Set objFileSystem = CreateObject("Scripting.FileSystemObject")
bComment = False
         
' Querying and verifying the arguments of the command

Set objArgumentsNamed = WScript.Arguments.Named
If objArgumentsNamed.Count = 0  Then 
   WScript.Quit(99)
End If

For Each objArgumentNamed in objArgumentsNamed
   Select Case Lcase(objArgumentNamed)
      Case "languagelist"
         strLangList = LCase(objArgumentsNamed(objArgumentNamed))
         arrLangList = Split(strLangList, ",")
      Case "comment"
         strComment = LCase(objArgumentsNamed(objArgumentNamed))
         If strComment = "yes" Then 
         		bComment = True
         End If 	
 	  Case "inputfile"
         strInputFile = LCase(objArgumentsNamed(objArgumentNamed))
         
         If Not objFileSystem.FileExists(strInputFile) Then  
            WScript.Quit(3)
         End If
      Case "outputfile"
         strOutputFile = LCase(objArgumentsNamed(objArgumentNamed))
         If objFileSystem.FileExists(strOutputFile) Then  
            WScript.Quit(4)
         End If
      Case Else
         WScript.Quit(5)
   End Select 
Next


If (Len(strLangList) > 0 Or bComment = True) And Len(strInputFile) > 0 And Len(strOutputFile) > 0 Then

' Selecting the nodes to change

	Set xmlDoc = CreateObject("Microsoft.XMLDOM")
	xmlDoc.Async = "False"
	xmlDoc.Load(strInputFile)
	Set objRoot = xmlDoc.documentElement


' Creating the language elements

   		If Len(strLangList) > 0 Then

			Set colNodes=xmlDoc.selectNodes("/strings/msg")
			For Each objNode in colNodes

	   			For Each strLang in arrLangList
		   			Set objRecord = xmlDoc.createElement(strLang)
					objNode.appendChild objRecord
					objNode.appendChild xmlDoc.createTextNode(vbCrLf & "		")
	   			Next
	   		Next
   		End If

' Converting the xml comments to <Comment> element

   		If bComment = True Then
			Set colNodes=xmlDoc.selectNodes("/strings/msg/en/comment()")
			For Each objNode in colNodes
			 	
			 	Set objPNode = objNode.parentNode.parentNode
			 	objPNode.setAttribute "Comment", objNode.text
				
				Set objPNode = objNode.parentNode
				objPNode.removeChild(objNode)
				
   			Next

   		End If
	
	xmlDoc.Save strOutputFile 
	
Else

' If parameters missing, skip execution
	WScript.Quit(98)

End If



' Clearing variables

Set strLangList = Nothing
Set strComment = Nothing
Set strInputFile = Nothing
Set strOutputFile = Nothing
Set strLang = Nothing
Set arrLangList = Nothing
Set bComment = Nothing
Set objArguments = Nothing
Set xmlDoc = Nothing
Set objRoot = Nothing
Set objNode = Nothing
Set objCNode = Nothing
Set objPNode = Nothing

